@@ -7,9 +7,16 @@
 # Base Imports
 
 import os
+import sys
 import os.path
 import pprint
 
+# Reconfigurations
+# ----------------
+
+sys.stdin.reconfigure(encoding='utf-8')
+sys.stdout.reconfigure(encoding='utf-8')
+
 # Environment
 
 from global_chem.environment.emerging_perfluoroalkyls import EmergingPerFluoroAlkyls
@@ -81,6 +88,11 @@ from global_chem.miscellaneous.open_smiles import OpenSmiles
 from global_chem.miscellaneous.amino_acids import AminoAcids
 from global_chem.miscellaneous.regex_patterns import CommonRegexPatterns
 
+# Sex
+
+from global_chem.sex.exsens.lube import Lube
+
+
 class Node:
 
     '''
@@ -280,7 +292,7 @@ class PrintTreeUtilities(object):
             fans = [get_repr(x) for x in node.children]
             labelled = PrintTreeUtilities.labelFan(node, PrintTreeUtilities.connectFans(fans))
             return labelled
-        print("\n".join(get_repr(node)))
+        print(str("\n".join(get_repr(node))))
 
 class GraphNetworkError(Exception):
 
@@ -302,7 +314,9 @@ class GlobalChem(object):
     __allow_update__ = False
 
     """
+    
     GlobalChem will be the master class of all variables, as the content store grows we can use this as the parent class.
+    
     """
 
     # NODE CONTRIBUTORS
@@ -341,6 +355,7 @@ class GlobalChem(object):
         'cimetidine_and_acyclovir': CimetidineAndAcyclovir,                      # Suliman Sharif
         'how_to_live_longer': HowToLiveLonger,                                   # Suliman Sharif
         'monoclonal_antibodies': MonoclonalAntibodies,                           # Asuka Orr & Suliman Sharif
+        'lube': Lube,                                                            # Daniel Khavrutskii & Suliman Sharif
         'common_regex_patterns': CommonRegexPatterns,                            # Chris Burke & Suliman Sharif
     }
 
@@ -356,6 +371,10 @@ class GlobalChem(object):
         self.root_node = ''
         self.deep_layer_count = 0
         self.verbose = verbose
+        self.splitter = '/'
+
+        if os.name == 'nt':
+            self.splitter = '\\'
 
     def check_available_nodes(self):
 
@@ -396,6 +415,7 @@ class GlobalChem(object):
         '''
 
         path_objects = []
+
         absolute_file_path = '/'.join(os.path.abspath(__file__).split('/')[:-1])
 
         for dirpath, dirnames, filenames in os.walk(absolute_file_path):
@@ -793,7 +813,7 @@ class GlobalChem(object):
         # Fetch All the File Paths
 
         path_objects = []
-        absolute_file_path = '/'.join(os.path.abspath(__file__).split('/')[:-1])
+        absolute_file_path = self.splitter.join(os.path.abspath(__file__).split(self.splitter)[:-1])
 
         for dirpath, dirnames, filenames in os.walk(absolute_file_path):
 
@@ -804,13 +824,13 @@ class GlobalChem(object):
                         'cli.py' not in file and \
                         'global_chem.py' not in file:
 
-                    object_path = os.path.join(''.join(dirpath.rsplit(absolute_file_path)), file).split('/')
+                    object_path = os.path.join(''.join(dirpath.rsplit(absolute_file_path)), file).split(self.splitter)
 
                     if debugger:
                         print ("Node Object Paths: %s: " % object_path)
 
                     path_objects.append(object_path)
-
+        
         # Add the objects recursively
 
         for chemical_object in path_objects:
@@ -1046,8 +1066,7 @@ class GlobalChem(object):
         _PRINT_NODE_KEY = {}
 
         path_objects = []
-        absolute_file_path = '/'.join(os.path.abspath(__file__).split('/')[:-1])
-        print(absolute_file_path)
+        absolute_file_path = self.splitter.join(os.path.dirname(os.path.realpath('__file__')).split(self.splitter)[:-1])
 
         for dirpath, dirnames, filenames in os.walk(absolute_file_path):
 
@@ -1058,9 +1077,8 @@ class GlobalChem(object):
                         'cli.py' not in file and \
                         'global_chem.py' not in file:
 
-                    object_path = os.path.join(''.join(dirpath.rsplit(absolute_file_path)), file).split('/')
+                    object_path = os.path.join(''.join(dirpath.rsplit(absolute_file_path)), file).split(self.splitter)
                     path_objects.append(object_path)
-                    print(object_path)
 
         # Add the objects recursively
 
@@ -1096,9 +1114,9 @@ class GlobalChem(object):
 
                         _PRINT_NODE_KEY[ parent ] = PrintNode(child, _PRINT_NODE_KEY[parent])
 
-        print(_PRINT_NODE_KEY)
+        print(str(_PRINT_NODE_KEY))
 
-        print(PrintTreeUtilities.printTrees(_PRINT_NODE_KEY['global_chem']))
+        print(str(PrintTreeUtilities.printTrees(_PRINT_NODE_KEY['global_chem'])))
 
     def print_deep_network(self):
 
@@ -1172,4 +1190,4 @@ class GlobalChem(object):
 
                 out_file.write(f'{key}\t{value}\t{node_name}\t{category}\t{tree_path}\n')
 
-        out_file.close()
\ No newline at end of file
+        out_file.close()
